decent\_bench.metrics
=====================


.. toctree::
   :maxdepth: 2

   decent_bench.metrics.metric_utils
   decent_bench.metrics.plot_metrics
   decent_bench.metrics.table_metrics

.. automodule:: decent_bench.metrics
   :members:
   :show-inheritance:
   :undoc-members:
